@@ -26,8 +26,7 @@ void
 FuzzHelper::doChecks()
 {
     Pl_Discard discard;
-    Pl_TIFFPredictor p(
-        "decoder", &discard, Pl_TIFFPredictor::a_decode, 16, 1, 8);
+    Pl_TIFFPredictor p("decoder", &discard, Pl_TIFFPredictor::a_decode, 16, 1, 8);
     p.write(const_cast<unsigned char*>(data), size);
     p.finish();
 }
